%define		vers		0.7.0
%define		patchlevel	p3
%define		name		polybori
%define		libname		%mklibname %{name} 0
%define		devname		%mklibname %{name} -d
%define		staticdevname	%mklibname %{name} -d -s
%define		polyboridir	%{_datadir}/%{name}
%define		SAGE_ROOT	%{_datadir}/sage
%define		SAGE_LOCAL	%{SAGE_ROOT}/local
%define		SAGE_DEVEL	%{SAGE_ROOT}/devel
%define		SAGE_DOC	%{SAGE_DEVEL}/doc
%define		SAGE_DATA	%{SAGE_ROOT}/data
%define		SAGE_PYTHONPATH	%{SAGE_ROOT}/site-packages

Name:		%{name}
Group:		Sciences/Mathematics
License:	GPL
Summary:	PolyBoRi is a C++ library for Polynomials over Boolean Rings
Epoch:		2
Version:	%{vers}.%{patchlevel}
Release:	%mkrel 2
Source0:	polybori-%{vers}.%{patchlevel}.tar.bz2
URL:		http://polybori.sourceforge.net/
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

BuildRequires:	doxygen
BuildRequires:	scons
BuildRequires:	boost-devel
BuildRequires:	ntl-devel
BuildRequires:	libm4ri-devel
BuildRequires:	texlive

%py_requires -d

Requires:	ipython >= 0.6

Patch0:		polybori-%{vers}.%{patchlevel}-sagemath.patch
Patch1:		polybori-%{vers}.%{patchlevel}-static-init-active_ring.patch

%description
PolyBoRi is implemented as a C++ library for Polynomials over
Boolean Rings, which provides high-level data types for Boolean
polynomials. A python-interface yields extensible algorithms for
computing Grbner bases over Boolean Rings.

%files
%defattr(-,root,root)
%{_bindir}/ipbori
%{_bindir}/PolyGUI
%dir %{polyboridir}
%{polyboridir}/*
%{_mandir}/man1/*

########################################################################
%package	-n python-%{name}
Group:		Development/Python
Summary:	Python bindings for PolyBoRi

%description	-n python-%{name}
PolyBoRi is a C++ library for Polynomials over Boolean Rings.
This package provides python bindings to %{name}.

%files		-n python-%{name}
%defattr(-,root,root)
%dir %{py_platlibdir}/%{name}
%{py_platlibdir}/%{name}/*

########################################################################
%package	-n %{libname}
Group:		System/Libraries
Summary:	PolyBoRi runtime libraries
Provides:	lib%{name} = %{version}-%{release}

%description	-n %{libname}
PolyBoRi runtime libraries.

%files		-n %{libname}
%defattr(-,root,root)
%{_libdir}/lib*.so.*

########################################################################
%package	-n %{devname}
Group:		Development/Other
Summary:	PolyBoRi development files
Provides:	%{name}-devel = %{version}-%{release}
Requires:	lib%{name} = %{version}-%{release}

%description	-n %{devname}
PolyBoRi development files.

%files		-n %{devname}
%defattr(-,root,root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*
%dir %{_includedir}/cudd
%{_includedir}/cudd/*
%{_libdir}/lib*.so

########################################################################
%package	-n %{staticdevname}
Group:		Development/Other
Summary:	PolyBoRi static libraries
Provides:	%{name}-static-devel = %{version}-%{release}
Requires:	lib%{name} = %{version}-%{release}
Requires:	%{name}-devel = %{version}-%{release}

%description	-n %{staticdevname}
PolyBoRi static libraries files.

%files		-n %{staticdevname}
%defattr(-,root,root)
%{_libdir}/*.a

########################################################################
%package	doc
Group:		Development/Other
Summary:	PolyBoRi documentation

%description	doc
PolyBoRi is implemented as a C++ library for Polynomials over
Boolean Rings, which provides high-level data types for Boolean
polynomials. A python-interface yields extensible algorithms for
computing Grbner bases over Boolean Rings.

%files		doc
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/*

########################################################################
%prep
%setup -q -n %{name}-%{vers}.%{patchlevel}/src/%{name}-0.7

cp ../../patches/SConstruct		./
cp ../../patches/PyPolyBoRi.py		pyroot/polybori/
cp ../../patches/pbori_routines_misc.h	polybori/include/
cp ../../patches/COrderedIter.h		polybori/include/
%patch0 -p3
#%#patch1 -p3

perl -pi -e 's|stub\.c||;' Cudd/util/Makefile

%build
%scons prepare-install	CCFLAGS="%{optflags}" CPPDEFINES=UNIX=1
%scons prepare-devel	CCFLAGS="%{optflags}" CPPDEFINES=UNIX=1

%install
%scons install devel-install	CCFLAGS="%{optflags}" 	\
	PREFIX=%{buildroot}%{_prefix}			\
	PYINSTALLPREFIX=%{buildroot}%{py_platlibdir}	\
	INSTALLDIR=%{buildroot}%{polyboridir}		\
	PYPREFIX=%{py_prefix}				\
	PYTHON=%{__python}				\
	DOCDIR=%{buildroot}%{_docdir}/%{name}		\
	MANDIR=%{buildroot}%{_mandir}			\
	LIBS="-lntl"					\
	CPPDEFINES=UNIX=1

chmod a+r -R %{buildroot}

# move libraries to %{_libdir}
if [ %{_prefix}/lib != %{_libdir} ]; then
    mkdir -p %{buildroot}/%{_libdir}
    mv -f %{buildroot}%{_prefix}/lib/lib* %{buildroot}/%{_libdir}
fi

perl -pi -e 's|%{buildroot}||g;' %{buildroot}%{polyboridir}/flags.conf

rm -f %{buildroot}%{_bindir}/ipbori
cat > %{buildroot}%{_bindir}/ipbori << EOF
#!/bin/sh
export CUR=\`pwd\`
export DOT_SAGE="\$HOME/.sage/"
export DOT_SAGENB="\$DOT_SAGE"
mkdir -p \$DOT_SAGE/{maxima,sympow,tmp}
export SAGE_TESTDIR=\$DOT_SAGE/tmp
export SAGE_ROOT="%{SAGE_ROOT}"
export SAGE_LOCAL="%{SAGE_LOCAL}"
export SAGE_DATA="%{SAGE_DATA}"
export SAGE_DEVEL="%{SAGE_DEVEL}"
export SAGE_DOC="%{SAGE_DOC}"
export PATH=$SAGE_LOCAL/bin:%{_datadir}/cdd/bin:\$PATH
export SINGULARPATH=%{_datadir}/singular/LIB
export SINGULAR_BIN_DIR=%{_datadir}/singular/%{_arch}
export PYTHONPATH="%{SAGE_PYTHONPATH}"
export SAGE_CBLAS=cblas
export SAGE_FORTRAN=%{_bindir}/gfortran
export SAGE_FORTRAN_LIB=\`gfortran --print-file-name=libgfortran.so\`
export SYMPOW_DIR="\$DOT_SAGE/sympow"
export LC_MESSAGES=C
export LC_NUMERIC=C
exec %{_datadir}/%{name}/ipbori/ipbori
EOF
chmod +x %{buildroot}%{_bindir}/ipbori

rm -f %{buildroot}%{_bindir}/PolyGUI
cat > %{buildroot}%{_bindir}/PolyGUI << EOF
#!/bin/sh
export CUR=\`pwd\`
export DOT_SAGE="\$HOME/.sage/"
export DOT_SAGENB="\$DOT_SAGE"
mkdir -p \$DOT_SAGE/{maxima,sympow,tmp}
export SAGE_TESTDIR=\$DOT_SAGE/tmp
export SAGE_ROOT="%{SAGE_ROOT}"
export SAGE_LOCAL="%{SAGE_LOCAL}"
export SAGE_DATA="%{SAGE_DATA}"
export SAGE_DEVEL="%{SAGE_DEVEL}"
export SAGE_DOC="%{SAGE_DOC}"
export PATH=$SAGE_LOCAL/bin:%{_datadir}/cdd/bin:\$PATH
export SINGULARPATH=%{_datadir}/singular/LIB
export SINGULAR_BIN_DIR=%{_datadir}/singular/%{_arch}
export PYTHONPATH="%{SAGE_PYTHONPATH}"
export SAGE_CBLAS=cblas
export SAGE_FORTRAN=%{_bindir}/gfortran
export SAGE_FORTRAN_LIB=\`gfortran --print-file-name=libgfortran.so\`
export SYMPOW_DIR="\$DOT_SAGE/sympow"
export LC_MESSAGES=C
export LC_NUMERIC=C
exec %{_datadir}/%{name}/gui/PolyGUI
EOF
chmod +x %{buildroot}%{_bindir}/PolyGUI

%clean
rm -rf %{buildroot}


%changelog
* Wed Jun 01 2011 Paulo Andrade <pcpa@mandriva.com.br> 2:0.7.0.p3-2mdv2011.0
+ Revision: 682294
- Correct scripts that sets sagemath environment variables

* Tue May 31 2011 Paulo Andrade <pcpa@mandriva.com.br> 2:0.7.0.p3-1
+ Revision: 682024
- Update to latest upstream release.

* Thu Mar 17 2011 Funda Wang <fwang@mandriva.org> 2:0.6.4.p6-2
+ Revision: 645716
- rebuild for new boost

* Mon Mar 07 2011 Paulo Andrade <pcpa@mandriva.com.br> 2:0.6.4.p6-1
+ Revision: 642753
- Update to newer patchlevel

* Tue Mar 01 2011 Paulo Andrade <pcpa@mandriva.com.br> 2:0.6.4.p4-3
+ Revision: 641193
- Rebuild with texlive

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 2:0.6.4.p4-2mdv2011.0
+ Revision: 592997
+ rebuild (emptylog)

* Thu Sep 23 2010 Paulo Andrade <pcpa@mandriva.com.br> 2:0.6.4.p4-1mdv2011.0
+ Revision: 580794
- Rework and adapt sagemath patches to correct crashes in doctests

* Wed Sep 22 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.4.p4-1mdv2011.0
+ Revision: 580443
- Update to patchlevel 4

* Wed Aug 25 2010 Funda Wang <fwang@mandriva.org> 1:0.6.4.p1-4mdv2011.0
+ Revision: 573033
- rebuild

* Thu Aug 05 2010 Funda Wang <fwang@mandriva.org> 1:0.6.4.p1-3mdv2011.0
+ Revision: 566294
- rebuild for new boost

* Wed Jul 14 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.4.p1-2mdv2011.0
+ Revision: 553402
+ rebuild (emptylog)

* Wed Jul 14 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.4.p1-1mdv2011.0
+ Revision: 552982
- Update to version 0.6.4, patchlevel 1.

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 1:0.6.3.20091028-7mdv2010.1
+ Revision: 501882
- rebuild for new boost
- remove unneeded explicit dependency on boost; autodependencies work
  correctly

* Thu Feb 04 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20091028-6mdv2010.1
+ Revision: 500942
- Rediff sagemath patch

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 1:0.6.3.20091028-5mdv2010.1
+ Revision: 500340
- rebuild for new boost

* Mon Feb 01 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20091028-4mdv2010.1
+ Revision: 499392
- Statically initialize global BooleEnv::ring_type active_ring

* Sat Jan 30 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20091028-3mdv2010.1
+ Revision: 498369
- Rebuild forcing use of Mandriva default optflags

* Wed Jan 27 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20091028-2mdv2010.1
+ Revision: 497395
- Rebuild and remove no longer needed _disable_ld_as_needed

* Fri Jan 22 2010 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20091028-1mdv2010.1
+ Revision: 495108
- Update to polybori 0.6.3 from 20091028

* Tue Nov 17 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.6.3.20090827-1mdv2010.1
+ Revision: 466704
- Update to polybori 0.6.3 from 20090827
- Merge sage patches into a single one
- Install python files in arch specific directory as there is a shared object
- Correct problem with documentation being installed twice
- Correct /usr/share/polybori/flags.conf (that is now used by sage 4.2 build)
- Correct ipbori to setup sage environment

* Wed Sep 09 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5rc.p9-6mdv2010.0
+ Revision: 435927
+ rebuild (emptylog)

* Sat Sep 05 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5rc.p9-4mdv2010.0
+ Revision: 431901
+ rebuild (emptylog)

* Fri Sep 04 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5rc.p9-2mdv2010.0
+ Revision: 431728
- allow rebuild when sagemath is installed
- link libraries with ntl

* Fri Sep 04 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5rc.p9-1mdv2010.0
+ Revision: 429130
- update to patchlevel 9

  + Funda Wang <fwang@mandriva.org>
    - rebuild for new libboost

* Wed Jul 15 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5-3mdv2010.0
+ Revision: 396471
- Update to latest upstream patchlevel 8.

* Tue May 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5-2mdv2010.0
+ Revision: 377421
+ rebuild (emptylog)

* Thu May 14 2009 Paulo Andrade <pcpa@mandriva.com.br> 1:0.5-1mdv2010.0
+ Revision: 375857
- Use an older version of polybori that works with sagemath.

* Thu May 14 2009 Paulo Andrade <pcpa@mandriva.com.br> 0.6-2mdv2010.0
+ Revision: 375808
- Initial import of polybori version 0.6.
  PolyBoRi is a C++ library for Polynomials over Boolean Rings
  http://polybori.sourceforge.net/
- polybori

